﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Net.Security;
using System.ServiceModel;
using HeuristicLab.Services.Access.DataTransfer;

namespace HeuristicLab.Services.Access {
  [ServiceContract(ProtectionLevel = ProtectionLevel.EncryptAndSign)]
  public interface IAccessService {

    #region Client
    [OperationContract]
    bool ClientExists(Guid id);

    [OperationContract]
    Client GetClient(Guid id);

    [OperationContract]
    IEnumerable<Client> GetClients();

    [OperationContract]
    Guid AddClient(Client client);

    [OperationContract]
    void UpdateClient(Client client);

    [OperationContract]
    void DeleteClient(Client client);
    #endregion

    #region ClientLog
    [OperationContract]
    ClientLog GetLastClientLog(Guid clientId);

    [OperationContract]
    IEnumerable<ClientLog> GetClientLogs(Guid clientId);

    [OperationContract]
    IEnumerable<ClientLog> GetClientLogsSince(DateTime startDate);

    [OperationContract]
    void AddClientLogEntry(ClientLog log);

    [OperationContract]
    void DeleteClientLogEntry(ClientLog log);
    #endregion

    #region Client Group
    [OperationContract]
    IEnumerable<ClientGroup> GetClientGroups();

    [OperationContract]
    Guid AddClientGroup(ClientGroup group);

    [OperationContract]
    void UpdateClientGroup(ClientGroup group);

    [OperationContract]
    void DeleteClientGroup(ClientGroup group);
    #endregion

    #region User
    [OperationContract]
    void Login();

    [OperationContract]
    IEnumerable<User> GetUsers();

    [OperationContract]
    User AddUser(User user);

    [OperationContract]
    void DeleteUser(User user);

    [OperationContract]
    void UpdateUser(User user);

    [OperationContract]
    void AddUserToRole(Role role, User user);

    [OperationContract]
    void RemoveUserFromRole(Role role, User user);

    [OperationContract]
    void ResetPassword(User user, string password);
    #endregion

    #region Role
    [OperationContract]
    IEnumerable<Role> GetRoles();

    [OperationContract]
    Role AddRole(Role role);

    [OperationContract]
    void UpdateRole(Role role);

    [OperationContract]
    void DeleteRole(Role role);

    [OperationContract]
    IEnumerable<Role> GetUserRoles(User user);
    #endregion

    #region UserGroup
    [OperationContract]
    IEnumerable<UserGroup> GetUserGroups();

    [OperationContract]
    UserGroup AddUserGroup(UserGroup group);

    [OperationContract]
    void UpdateUserGroup(UserGroup group);

    [OperationContract]
    void DeleteUserGroup(UserGroup group);
    #endregion
  }
}
